// You must provide a vertex and fragment shader to OpenGL.

// You have to specify the version of the shader language used.
// GLSL 1.50 is sufficient for our purposes.
#version 150 core

// Minimally, we need to receive the vertex position as x, y, z coordinates.
// The relationship between this local variable and the data are
// set in the OpenGL init(...) method provided by the implementing Java class.
in vec3 position;

// The vertex color data: red, green, blue (0.0-1.0).
in vec3 color;

// These are the user variables in which values are passed out of the shader.
// We only send out the vertex color.
out vec3 Color;

void main()
{
    // Here we will later apply lots of transformations, but for now,
    // we simple pass the coordinates on for further processing by OpenGL in 
    // homogeneous coordinate form.
    // Homogeneous coordinate form is (x, y, z, alpha), alpha=1.0=opaque
    gl_Position = vec4(position, 1.0);

    // And pass the color on. OpenGL will handle interpolating areas 
    // between vertices.
    Color = color;
}
